@@ -1,7 +1,5 @@
 #include <thunar/thunar-marshal.h>
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,22 +47,60 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
-/* BOOLEAN:POINTER (thunar-marshal.list:1) */
+/* BOOLEAN:BOOLEAN (thunar-marshal.list:1) */
 void
-_thunar_marshal_BOOLEAN__POINTER (GClosure     *closure,
-                                  GValue       *return_value G_GNUC_UNUSED,
+_thunar_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
+                                  GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
-                                                     gpointer     arg_1,
-                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__BOOLEAN) (gpointer data1,
+                                                     gboolean arg1,
+                                                     gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__BOOLEAN callback;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_boolean (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:POINTER (thunar-marshal.list:2) */
+void
+_thunar_marshal_BOOLEAN__POINTER (GClosure     *closure,
+                                  GValue       *return_value,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
+                                  gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer data1,
+                                                     gpointer arg1,
+                                                     gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -89,20 +125,20 @@ _thunar_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (thunar-marshal.list:2) */
+/* BOOLEAN:VOID (thunar-marshal.list:3) */
 void
 _thunar_marshal_BOOLEAN__VOID (GClosure     *closure,
-                               GValue       *return_value G_GNUC_UNUSED,
+                               GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
-                                                  gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer data1,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -126,22 +162,61 @@ _thunar_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* FLAGS:OBJECT,OBJECT (thunar-marshal.list:3) */
+/* BOOLEAN:INT (thunar-marshal.list:4) */
+void
+_thunar_marshal_BOOLEAN__INT (GClosure     *closure,
+                              GValue       *return_value,
+                              guint         n_param_values,
+                              const GValue *param_values,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
+                              gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__INT) (gpointer data1,
+                                                 gint arg1,
+                                                 gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__INT callback;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__INT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_int (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* FLAGS:OBJECT,OBJECT (thunar-marshal.list:5) */
 void
 _thunar_marshal_FLAGS__OBJECT_OBJECT (GClosure     *closure,
-                                      GValue       *return_value G_GNUC_UNUSED,
+                                      GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
-  typedef guint (*GMarshalFunc_FLAGS__OBJECT_OBJECT) (gpointer     data1,
-                                                      gpointer     arg_1,
-                                                      gpointer     arg_2,
-                                                      gpointer     data2);
-  register GMarshalFunc_FLAGS__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef guint (*GMarshalFunc_FLAGS__OBJECT_OBJECT) (gpointer data1,
+                                                      gpointer arg1,
+                                                      gpointer arg2,
+                                                      gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_FLAGS__OBJECT_OBJECT callback;
   guint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -167,22 +242,22 @@ _thunar_marshal_FLAGS__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_flags (return_value, v_return);
 }
 
-/* FLAGS:STRING,FLAGS (thunar-marshal.list:4) */
+/* FLAGS:STRING,FLAGS (thunar-marshal.list:6) */
 void
 _thunar_marshal_FLAGS__STRING_FLAGS (GClosure     *closure,
-                                     GValue       *return_value G_GNUC_UNUSED,
+                                     GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef guint (*GMarshalFunc_FLAGS__STRING_FLAGS) (gpointer     data1,
-                                                     gpointer     arg_1,
-                                                     guint        arg_2,
-                                                     gpointer     data2);
-  register GMarshalFunc_FLAGS__STRING_FLAGS callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef guint (*GMarshalFunc_FLAGS__STRING_FLAGS) (gpointer data1,
+                                                     gpointer arg1,
+                                                     guint arg2,
+                                                     gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_FLAGS__STRING_FLAGS callback;
   guint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -208,7 +283,7 @@ _thunar_marshal_FLAGS__STRING_FLAGS (GClosure     *closure,
   g_value_set_flags (return_value, v_return);
 }
 
-/* VOID:STRING,STRING (thunar-marshal.list:5) */
+/* VOID:STRING,STRING (thunar-marshal.list:7) */
 void
 _thunar_marshal_VOID__STRING_STRING (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -217,13 +292,13 @@ _thunar_marshal_VOID__STRING_STRING (GClosure     *closure,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -245,7 +320,7 @@ _thunar_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT64,UINT,UINT,UINT (thunar-marshal.list:6) */
+/* VOID:UINT64,UINT,UINT,UINT (thunar-marshal.list:8) */
 void
 _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
                                              GValue       *return_value G_GNUC_UNUSED,
@@ -254,15 +329,15 @@ _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
                                              gpointer      invocation_hint G_GNUC_UNUSED,
                                              gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT64_UINT_UINT_UINT) (gpointer     data1,
-                                                            guint64      arg_1,
-                                                            guint        arg_2,
-                                                            guint        arg_3,
-                                                            guint        arg_4,
-                                                            gpointer     data2);
-  register GMarshalFunc_VOID__UINT64_UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__UINT64_UINT_UINT_UINT) (gpointer data1,
+                                                            guint64 arg1,
+                                                            guint arg2,
+                                                            guint arg3,
+                                                            guint arg4,
+                                                            gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__UINT64_UINT_UINT_UINT callback;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -286,7 +361,7 @@ _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED,UINT,STRING (thunar-marshal.list:7) */
+/* VOID:UINT,BOXED,UINT,STRING (thunar-marshal.list:9) */
 void
 _thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -295,15 +370,15 @@ _thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
                                               gpointer      invocation_hint G_GNUC_UNUSED,
                                               gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_BOXED_UINT_STRING) (gpointer     data1,
-                                                             guint        arg_1,
-                                                             gpointer     arg_2,
-                                                             guint        arg_3,
-                                                             gpointer     arg_4,
-                                                             gpointer     data2);
-  register GMarshalFunc_VOID__UINT_BOXED_UINT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__UINT_BOXED_UINT_STRING) (gpointer data1,
+                                                             guint arg1,
+                                                             gpointer arg2,
+                                                             guint arg3,
+                                                             gpointer arg4,
+                                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOXED_UINT_STRING callback;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -327,7 +402,7 @@ _thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED (thunar-marshal.list:8) */
+/* VOID:UINT,BOXED (thunar-marshal.list:10) */
 void
 _thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -336,13 +411,13 @@ _thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_BOXED) (gpointer     data1,
-                                                 guint        arg_1,
-                                                 gpointer     arg_2,
-                                                 gpointer     data2);
-  register GMarshalFunc_VOID__UINT_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__UINT_BOXED) (gpointer data1,
+                                                 guint arg1,
+                                                 gpointer arg2,
+                                                 gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOXED callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -364,7 +439,7 @@ _thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (thunar-marshal.list:9) */
+/* VOID:OBJECT,OBJECT (thunar-marshal.list:11) */
 void
 _thunar_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -373,13 +448,13 @@ _thunar_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
 
   g_return_if_fail (n_param_values == 3);
 
